add_well_known_node

Function add_well_known_node 

pub fn add_well_known_node<T: Config>(
    node: OpaquePeerId,
    owner: <<T as Config>::Lookup as StaticLookup>::Source,
)
Add a node to the set of well known nodes. If the node is already claimed, the owner will be updated and keep the existing additional connection unchanged.

May only be called from T::AddOrigin.

  • node: identifier of the node.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::add_well_known_node.